@@ -15,6 +15,7 @@ type diffCmdConfig struct {
 	ScriptContents bool                  `json:"scriptContents" mapstructure:"scriptContents" yaml:"scriptContents"`
 	include        *chezmoi.EntryTypeSet
 	init           bool
+	parentDirs     bool
 	recursive      bool
 }
 
@@ -38,6 +39,8 @@ func (c *Config) newDiffCmd() *cobra.Command {
 	diffCmd.Flags().VarP(c.Diff.include, "include", "i", "Include entry types")
 	diffCmd.Flags().BoolVar(&c.Diff.init, "init", c.Diff.init, "Recreate config file from template")
 	diffCmd.Flags().StringVar(&c.Diff.Pager, "pager", c.Diff.Pager, "Set pager")
+	diffCmd.Flags().
+		BoolVarP(&c.Diff.parentDirs, "parent-dirs", "P", c.apply.parentDirs, "Print the diff of all parent directories")
 	diffCmd.Flags().BoolVarP(&c.Diff.recursive, "recursive", "r", c.Diff.recursive, "Recurse into subdirectories")
 	diffCmd.Flags().BoolVar(&c.Diff.Reverse, "reverse", c.Diff.Reverse, "Reverse the direction of the diff")
 	diffCmd.Flags().BoolVar(&c.Diff.ScriptContents, "script-contents", c.Diff.ScriptContents, "Show script contents")
@@ -47,10 +50,11 @@ func (c *Config) newDiffCmd() *cobra.Command {
 
 func (c *Config) runDiffCmd(cmd *cobra.Command, args []string) (err error) {
 	return c.applyArgs(cmd.Context(), c.destSystem, c.DestDirAbsPath, args, applyArgsOptions{
-		cmd:       cmd,
-		filter:    chezmoi.NewEntryTypeFilter(c.Diff.include.Bits(), c.Diff.Exclude.Bits()),
-		init:      c.Diff.init,
-		recursive: c.Diff.recursive,
-		umask:     c.Umask,
+		cmd:        cmd,
+		filter:     chezmoi.NewEntryTypeFilter(c.Diff.include.Bits(), c.Diff.Exclude.Bits()),
+		init:       c.Diff.init,
+		parentDirs: c.Diff.parentDirs,
+		recursive:  c.Diff.recursive,
+		umask:      c.Umask,
 	})
 }
