@@ -4,6 +4,7 @@ import (
 	"bufio"
 	"bytes"
 	_ "embed"
+	"encoding/hex"
 	"errors"
 	"flag"
 	"fmt"
@@ -97,6 +98,7 @@ func TestScript(t *testing.T) {
 			"cmpmod":         cmdCmpMod,
 			"edit":           cmdEdit,
 			"expandenv":      cmdExpandEnv,
+			"hexdecode":      cmdHexDecode,
 			"httpd":          cmdHTTPD,
 			"isdir":          cmdIsDir,
 			"issymlink":      cmdIsSymlink,
@@ -260,6 +262,33 @@ func cmdHTTPD(ts *testscript.TestScript, neg bool, args []string) {
 	ts.Setenv("HTTPD_URL", server.URL)
 }
 
+// cmdHexDecode decodes each argument, which must be a file with the extension
+// .hex, writing the result to the same path but without the .hex extension.
+func cmdHexDecode(ts *testscript.TestScript, neg bool, args []string) {
+	if neg {
+		ts.Fatalf("unsupported: ! hexdecode")
+	}
+	for _, arg := range args {
+		filename := ts.MkAbs(arg)
+		if filepath.Ext(filename) != ".hex" {
+			ts.Fatalf("%s: no .hex extension", arg)
+		}
+		hexData, err := os.ReadFile(filename)
+		if err != nil {
+			ts.Fatalf("%s: %v", arg, err)
+		}
+		hexData = regexp.MustCompile(`(?m)#.*$`).ReplaceAll(hexData, nil)
+		hexData = regexp.MustCompile(`\s+`).ReplaceAll(hexData, nil)
+		data := make([]byte, hex.DecodedLen(len(hexData)))
+		if _, err := hex.Decode(data, hexData); err != nil {
+			ts.Fatalf("%s: %v", arg, err)
+		}
+		if err := os.WriteFile(strings.TrimSuffix(filename, ".hex"), data, 0o666); err != nil {
+			ts.Fatalf("%s: %v", arg, err)
+		}
+	}
+}
+
 // cmdIsDir succeeds if all of its arguments are directories.
 func cmdIsDir(ts *testscript.TestScript, neg bool, args []string) {
 	for _, arg := range args {
@@ -751,7 +780,7 @@ func goosCondition(cond string) (result, valid bool) {
 	if !strings.HasPrefix(cond, "(") || !strings.HasSuffix(cond, ")") {
 		result = false
 		valid = false
-		return
+		return result, valid
 	}
 	cond = strings.TrimPrefix(cond, "(")
 	cond = strings.TrimSuffix(cond, ")")
@@ -766,7 +795,7 @@ func goosCondition(cond string) (result, valid bool) {
 		if _, ok := imports.KnownOS[term]; !ok {
 			if _, ok := imports.KnownArch[term]; !ok {
 				valid = false
-				return
+				return result, valid
 			}
 		}
 	}
@@ -780,16 +809,16 @@ func goosCondition(cond string) (result, valid bool) {
 		switch {
 		case term == runtime.GOOS || term == "unix" && imports.UnixOS[runtime.GOOS]:
 			result = true
-			return
+			return result, valid
 		case term == runtime.GOARCH:
 			result = true
-			return
+			return result, valid
 		}
 	}
 
 	// Otherwise, the condition is false.
 	result = false
-	return
+	return result, valid
 }
 
 func prependDirToPath(dir, pathStr string) string {
